#[non_exhaustive]pub struct Chain<T, U> { /* private fields */ }🔬This is a nightly-only experimental API. (
alloc_io #154046)Expand description
Implementations
Sourceimpl<T, U> Chain<T, U>
impl<T, U> Chain<T, U>
1.20.0 · Sourcepub fn into_inner(self) -> (T, U)
pub fn into_inner(self) -> (T, U)
Consumes the Chain, returning the wrapped readers.
Examples
1.20.0 · Sourcepub fn get_ref(&self) -> (&T, &U)
pub fn get_ref(&self) -> (&T, &U)
Gets references to the underlying readers in this Chain.
Care should be taken to avoid modifying the internal I/O state of the
underlying readers as doing so may corrupt the internal state of this
Chain.
Examples